@@ -1,5 +1,5 @@
-from .Base import *
+from .Base import Base
 
 
 class Issuer(Base):
-    pass
\ No newline at end of file
+    pass
